pub fn preload_local_candle(params: &CandleRunParams) -> Result<()>Expand description
Optionally preload the model so the first request is fast.
pub fn preload_local_candle(params: &CandleRunParams) -> Result<()>Optionally preload the model so the first request is fast.